@@ -22,14 +22,14 @@ KML_DEFINE_TAG_HANDLER_GX22( flyToMode )
 
 GeoNode* KmlflyToModeTagHandler::parse( GeoParser& parser ) const
 {
-    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_flyToMode ) );
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_flyToMode)));
 
     QString content = parser.readElementText().trimmed();
 
     GeoDataFlyTo::FlyToMode mode;
-    if( content == "smooth" ) {
+    if (content == QLatin1String("smooth")) {
         mode = GeoDataFlyTo::Smooth;
-    } else if( content == "bounce" ) {
+    } else if (content == QLatin1String("bounce")) {
         mode = GeoDataFlyTo::Bounce;
     } else {
         mDebug() << "Unknown mode " << content << ", using 'bounce' instead.";
