@@ -151,7 +151,7 @@ void GeoSceneTileDataset::setTileLevels(const QString &tileLevels)
     }
 
     const QStringList values = tileLevels.split(QLatin1Char(','));
-    foreach(const QString &value, values) {
+    for(const QString &value: values) {
         bool canParse(false);
         int const tileLevel = value.trimmed().toInt(&canParse);
         if (canParse && tileLevel >= 0 && tileLevel < 100) {
@@ -162,7 +162,7 @@ void GeoSceneTileDataset::setTileLevels(const QString &tileLevels)
     }
 
     if (!m_tileLevels.isEmpty()) {
-        qSort(m_tileLevels);
+        std::sort(m_tileLevels.begin(), m_tileLevels.end());
         m_minimumTileLevel = m_tileLevels.first();
         m_maximumTileLevel = m_tileLevels.last();
     }
@@ -252,16 +252,16 @@ QUrl GeoSceneTileDataset::downloadUrl( const TileId &id ) const
         mDebug() << "No download URL specified for tiles stored in "
                  << m_sourceDir << ", falling back to " << defaultUrl.toString();
         return m_serverLayout->downloadUrl(defaultUrl, id);
+    } else if (m_downloadUrls.size() == 1) {
+        return m_serverLayout->downloadUrl(*m_nextUrl, id);
+    } else {
+        if (m_nextUrl == m_downloadUrls.constEnd()) {
+            m_nextUrl = m_downloadUrls.constBegin();
+        }
+        const QUrl url = m_serverLayout->downloadUrl(*m_nextUrl, id);
+        ++m_nextUrl;
+        return url;
     }
-
-    if ( m_nextUrl == m_downloadUrls.constEnd() )
-        m_nextUrl = m_downloadUrls.constBegin();
-
-    const QUrl url = m_serverLayout->downloadUrl( *m_nextUrl, id );
-
-    ++m_nextUrl;
-
-    return url;
 }
 
 void GeoSceneTileDataset::addDownloadUrl( const QUrl & url )
@@ -278,8 +278,6 @@ QString GeoSceneTileDataset::relativeTileFileName( const TileId &id ) const
     QString relFileName;
 
     switch ( m_storageLayoutMode ) {
-    default:
-        mDebug() << Q_FUNC_INFO << "Invalid storage layout mode! Falling back to default.";
     case GeoSceneTileDataset::Marble:
         relFileName = QString( "%1/%2/%3/%3_%4.%5" )
             .arg( themeStr() )
