@@ -11,7 +11,6 @@
 #ifndef MARBLE_GEOWRITER_H
 #define MARBLE_GEOWRITER_H
 
-#include "GeoDataFeature.h"
 #include "marble_export.h"
 
 #include <QXmlStreamWriter>
@@ -20,6 +19,8 @@
 namespace Marble
 {
 
+class GeoNode;
+
 /**
  * @brief Standard Marble way of writing XML
  * This class is intended to be a standardised way of writing XML for marble.
@@ -83,6 +84,7 @@ public:
 
 private:
     friend class GeoTagWriter;
+    friend class GeoDataDocumentWriter;
     bool writeElement( const GeoNode* object );
 
 private:
